@@ -46,7 +46,7 @@ class ExpaiModelExplainer:
         response = self.sess.request("GET",
                                     self.server_name + "/api/explain/{}".format(self.model_id), headers=self.headers, json=json)
 
-        return response.json()
+        return generate_response(response, 'shap_values')
 
     def explain_model(self, sample_name: str = None, sample_id: str = None, indexes: list = None, shap: bool = True, lime: bool = False):
         assert sample_name is not None or sample_id is not None, "You must provide a sample name or id for the explanation"
@@ -71,7 +71,7 @@ class ExpaiModelExplainer:
         response = self.sess.request("GET",
                                     self.server_name + "/api/explain/{}/graphics".format(self.model_id), headers=self.headers, json=json)
 
-        return response.json()
+        return generate_response(response, 'visualizations')
 
     def explain_sample(self, sample_name: str = None, sample_id: str = None, index: list = None, shap: bool = True, lime: bool = False):
         assert sample_name is not None or sample_id is not None, "You must provide a sample name or id for the explanation"
@@ -96,7 +96,7 @@ class ExpaiModelExplainer:
                                     self.server_name + "/api/explain/{}/sample/graphics".format(self.model_id), headers=self.headers, json=json)
 
         if response.ok:
-            return response.json().json()['visualizations']['single_force_plot']
+            return response.json()['visualizations']['single_force_plot']
         else:
             if 'error' in response.json().keys():
                 logging.error("There was an error deleting the sample. Please, check the details below. \n {}".format(
