@@ -37,7 +37,7 @@ class ExpaiProject:
                     if model['model_name_des'] == exact_search:
                         return model
             logging.error(
-                "We could not find a sample with this exact name. Try again or consider using search_by parameter to find similar samples")
+                "We could not find a model with this exact name. Try again or consider using search_by parameter to find similar samples")
             return None
 
         elif search_by is not None:
